@@ -472,17 +472,17 @@ annotation e = do
 multiscripts :: Element -> MML Exp
 multiscripts e = do
   let (xs, pres) = break ((== "mprescripts") . name) (elChildren e)
-  let row'' e' = if name e' == "none"
-                    then return $ EGrouped []
-                    else row e'
-  xs' <- mapM row'' xs
+  let row' e' = if name e' == "none"
+                   then return $ EGrouped []
+                   else row e'
+  xs' <- mapM row' xs
   let base =
         case xs' of
           [x]       -> x
           [x,y]     -> ESub x y
           (x:y:z:_) -> ESubsup x y z
           []        -> EGrouped []
-  pres' <- mapM row'' $ drop 1 pres
+  pres' <- mapM row' $ drop 1 pres
   return $
     case pres' of
         (x:y:_) -> EGrouped [ESubsup (EGrouped []) x y, base]
@@ -598,11 +598,7 @@ err e = name e <> maybe "" (\x -> " line " <> T.pack (show x)) (elLine e)
 -- Kept as String for Text.XML.Light
 findAttrQ :: String -> Element -> MML (Maybe T.Text)
 findAttrQ s e = do
-  inherit <- case (name e, s) of
-            ("mfenced", "open") -> return Nothing
-            ("mfenced", "close") -> return Nothing
-            ("mfenced", "separators") -> return Nothing
-            _ -> asks (lookupAttrQ s . attrs)
+  inherit <- asks (lookupAttrQ s . attrs)
   return $ fmap T.pack $
     findAttr (QName s Nothing Nothing) e
       <|> inherit
